/*
 * Version: Open Software License v. 2.1
 *
 * The contents of this file are subject to the Open Software License Version
 * 2.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.opensource.org/licenses/osl-2.1.php
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the FacebookLike.
 *
 * The Initial Developer of the Original Code is
 * SimilarWeb Ltd.
 *
 * Portions created by the Initial Developer are Copyright (C) 2008
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * */

var FacebookLikeUninstallObserver = function() {
    var pub = {};

    pub.init = function() {
        Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService).addObserver(this, "em-action-requested", false);
    };

    pub.observe = function(subject, topic, data) {
        try {
            if (topic!="em-action-requested")
                return;
            var updateItem = subject.QueryInterface(Components.interfaces.nsIUpdateItem);
            if (updateItem.id!="{45e16761-660c-41a4-984f-56986fba2137}")
                return;
        } catch (e) {}
    };

    pub.uninit = function() {
        Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService).removeObserver(this, "em-action-requested");
    };

    return pub;
}();

 
var FacebookLike = function() {
    var pub = {};

// public constants
    pub.BUNDLE = Components.classes["@mozilla.org/intl/stringbundle;1"].getService(Components.interfaces.nsIStringBundleService)
                               .createBundle("chrome://facebooklike/locale/facebooklike.properties");
    pub.CURRENT_VERSION = FacebookLikeUtils.getVersion();
    pub.PREFS = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("extensions.facebooklike.")

// public vars
    pub.mUrl = null;
    
// private vars
    var mOldUrl = null;

// public functions
    pub.init = function() {
        FacebookLikeUninstallObserver.init();
    }

    pub.initAfterWindowLoad = function() {
        window.setTimeout(function() { FacebookLike.initAfterWindowLoadActual(); }, 1000);
    }

    pub.initAfterWindowLoadActual = function() {
        try {
            if (!gBrowser)
                return;
        } catch (e) { return; }
        FacebookLikeUninstallObserver.init();
        // new install
        if (FacebookLike.PREFS.getCharPref("version")=="0") {
            FacebookLike.PREFS.setCharPref("version", pub.CURRENT_VERSION.toString());
        // on update
        } else if (FacebookLike.PREFS.getCharPref("version")!=pub.CURRENT_VERSION) {
            FacebookLike.PREFS.setCharPref("version", pub.CURRENT_VERSION.toString());
        }
        // insert toolbar button
        var palette = document.getElementById('navigator-toolbox').palette;
        toolbarButton = palette.getElementsByAttribute('id', 'FacebookLikeStatusbarButton')[0];
        var addressBarContainer = document.getElementById('urlbar-container');
        if (!addressBarContainer)
            addressBarContainer = document.getElementById('search-container');
        if (!addressBarContainer)
            addressBarContainer = document.getElementById('navigator-throbber');
        try {
            if (addressBarContainer && addressBarContainer.parentNode)
                addressBarContainer.parentNode.insertBefore(toolbarButton, addressBarContainer);       
            else if (addressBarContainer)
                addressBarContainer.insertBefore(toolbarButton, addressBarContainer);       
        } catch (e) { }       
        // initialize toolbar button text
        var toolbarButton = document.getElementById('FacebookLikeStatusbarButton');
        var hideToolbarButtonText = "true";
        if (FacebookLike.PREFS.getBoolPref("hideToolbarButtonText"))
            hideToolbarButtonText = "false";
        toolbarButton.setAttribute("hideToolbarButtonText", hideToolbarButtonText);
    }

    pub.uninitAfterWindowUnload = function() {
        try {
            if (!gBrowser)
                return;
            FacebookLikeUninstallObserver.uninit();
        } catch (e) {}
    }

    pub.toggleLikePopup = function(event) {
        var url = encodeURIComponent((window.top.getBrowser().selectedBrowser.contentWindow.location.href.toString()))
                      .replace(/!/g, '%21').replace(/'/g, '%27').replace(/\(/g, '%28').replace(/\)/g, '%29').replace(/\*/g, '%2A');
        var popup = content.document.getElementById("facebookLikeAddon_Popup");
        if (popup) {
            if (popup.style.display=="block")
                popup.style.display = "none";
            else
                popup.style.display = "block";
            return;
        }
        popup = content.document.createElement("div");
        popup.setAttribute("onmouseout", "this.style.display = 'none';");
        popup.setAttribute("onmouseover", "this.style.display = 'block';");
        popup.setAttribute("id", "facebookLikeAddon_Popup");
        popup.setAttribute("style", "height: 30px; width: 315px; right: 0; margin: 0; padding-top: 5px; padding-left: 5px; position: fixed; bottom: 0; background-color: white; border: grey 1px solid; z-index: 100000;");
        popup.innerHTML = "<iframe style='border:none; overflow:hidden; width:310px; height:35px;' src='http://www.facebook.com/plugins/like.php?href=" + url + "&amp;layout=standard&amp;show_faces=false&amp;width=300&amp;action=like&amp;font&amp;colorscheme=light&amp;height=35' scrolling='no' frameborder='0' allowTransparency='true'></iframe>";
        var body = content.document.getElementsByTagName("body")[0];
        body.appendChild(popup);
    }

    return pub;
}();

window.addEventListener("load", function() {FacebookLike.initAfterWindowLoad()}, false);
window.addEventListener("unload", function() {FacebookLike.uninitAfterWindowUnload()}, false);



