/*
 * Version: Open Software License v. 2.1
 *
 * The contents of this file are subject to the Open Software License Version
 * 2.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.opensource.org/licenses/osl-2.1.php
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the FacebookLike.
 *
 * The Initial Developer of the Original Code is
 * SimilarWeb Ltd.
 *
 * Portions created by the Initial Developer are Copyright (C) 2008
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * */

var FacebookLikeUtils = function() {
    var pub = {};

// private properties
    var gSessionId = null;
    const IS_DEBUG_MODE = false;

// public functions
    pub.isWebUrl = function(url) {
        if (url.match(/^(http:\/\/localhost\/)/) || url.match(/^(about:)/) || url.match(/^(file:)/) || url.match(/^(chrome:)/) || url.match(/^(javascript:)/) || url=="unknown")
            return false;
        return true;
    }
    
    pub.openUrl = function(queryUrl, isSearchQuery, userUrl) {
        if (userUrl)
            queryUrl = FacebookLikeUtils.replaceVarsInString(queryUrl, userUrl);
        if (window.content.location.href==queryUrl || window.content.location.href=="about:blank")
            window.content.document.location.href = queryUrl;
        else
            getBrowser().selectedTab = getBrowser().addTab(queryUrl);
    }
       
    pub.replaceVarsInString = function(string, userUrl) {
        var noWwwDomain = pub.getDomain(userUrl, "noWwwDomain");
        string = string.replace(/\$url/g, userUrl);
        string = string.replace(/\$domain/g, pub.getDomain(userUrl));
        string = string.replace(/\$shortDomain/g, pub.getDomain(userUrl, "shortDomain"));
        string = string.replace(/\$noWwwDomain/g, noWwwDomain);
        string = string.replace(/\$noSubOrWwwDomain/g, pub.getDomain(userUrl, "noSubOrWwwDomain"));
        if (noWwwDomain)
            string = string.replace(/\$firstChar/g, noWwwDomain.charAt(0));
        return string;
    }
    
    pub.getDomain = function(url, type) {
        if (!url)
            return;
        var domain =  url.split("/");
        if (!domain[2])
            return url;
        if (type=="shortDomain") {
            return domain[2];
        } else if (type=="noWwwDomain") {
            if (domain[2].indexOf("www.")==0)
                return domain[2].slice(4, domain[2].length);
            else
                return domain[2];
        } else if (type=="noSubOrWwwDomain") {
            domain = domain[2].replace(new RegExp(/^www\./i),"");
            if (domain.match(new RegExp(/\.[a-z]{2,3}\.[a-z]{2}$/i))) { // .??.?? or .???.?? (ex: .co.uk or .com.au)
                domain = domain.split(".");
                if (domain.length==5)
                   domain = domain[2] + "." + domain[3] + "." + domain[4];
                else if (domain.length==4)
                   domain = domain[1] + "." + domain[2] + "." + domain[3];
                else
                   domain = domain[0] + "." + domain[1] + "." + domain[2];
            } else {
                domain = domain.split(".");
                if (domain.length==4)
                    domain = domain[2] + "." + domain[3];
                else if (domain.length==3)
                   domain = domain[1] + "." + domain[2];
                else
                   domain = domain[0] + "." + domain[1];
            }
            return domain;
        } else {
            return domain[0] + "//" + domain[2] + "/";
        }
    }

    pub.openButtonMenu = function(currentButton) {
        if (!currentButton || currentButton.open)
            return;
        var anotherButton = null;
        var buttons = currentButton.parentNode.getElementsByTagName("toolbarbutton");                
        for (var buttonsCounter = 0; buttonsCounter < buttons.length; buttonsCounter++) {
            anotherButton = buttons.item(buttonsCounter);
            if (anotherButton && anotherButton!=currentButton && anotherButton.open) {
                anotherButton.open = false;
                currentButton.open = true;
                break;
            }
        }
    }
    
    pub.getVersion = function() {
        var extensionManager = Components.classes["@mozilla.org/extensions/manager;1"].getService(Components.interfaces.nsIExtensionManager);  
        var addon = extensionManager.getItemForID("{45e16761-660c-41a4-984f-56986fba2137}");  
        return addon.version; 
    }

    pub.debug = function(msg, isFull) {
        if (!IS_DEBUG_MODE)
            return;
        var date = new Date();
        var timeStr = date.getMinutes() + ":" + date.getSeconds() + ":" + date.getMilliseconds();
        var prefix = "SP (" + timeStr + ") ";
        try {
            a.b = b.c;
        } catch (e) {
            if (isFull) {
                dump(prefix + ": " + e.stack + "\n");
                return;
            }
            var s = "chrome://facebooklike/content/";
            var index = e.stack.indexOf(s);
            index = e.stack.indexOf(s, index+1);
            var index2 = e.stack.indexOf("\n", index+1);
            var lineNumber = e.stack.substring(index+s.length, index2);
            dump(prefix + lineNumber + ": " + msg + "\n");
            // output to error console
            window.setTimeout(function() { throw new Error("[debug] " + msg); }, 0);
        }
    }

    pub.debugException = function(e) {
        pub.debug("An exception occurred. Error name: " + e.name + ". Error message: " + e.message, true);
    }

    pub.openUrlFromDialog = function(url) {
        var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);
        var win = wm.getMostRecentWindow("navigator:browser");
        var gBrowser = win.getBrowser();
        gBrowser.loadOneTab(url, null, null, null, false, false);
    }
    
    pub.openMailTo = function() {
//        parent.location = "mailto:?subject=You should be using FacebookLike&body=Go to http://www.facetweak.com/ to check out the FacebookLike Firefox add-on!";       
    }

    pub.htmlParser = function(htmlString) {
        var parseDOM = content.document.createElement('div');
        parseDOM.appendChild(Components.classes["@mozilla.org/feed-unescapehtml;1"]
           .getService(Components.interfaces.nsIScriptableUnescapeHTML)
           .parseFragment(htmlString, false, null, parseDOM));
        return parseDOM;
    }

    return pub;
}();